@@ -2,7 +2,7 @@ package Tie::Hash::Attribute;
 use 5.006;
 use strict;
 use warnings FATAL => 'all';
-our $VERSION = '1.01';
+our $VERSION = '1.02';
 our @ISA = 'Tie::Hash';
 
 our $ATTR_SORT = 0;
@@ -37,9 +37,10 @@ sub _mk_str {
     my @keys = $ATTR_SORT ? sort keys %$hash : keys %$hash;
     for my $key (@keys) {
         next if $seen{lc$key}++;
-        my $val = defined($hash->{$key}) ? $hash->{$key} : '';
+        my $val = $hash->{$key};
         $val  = _stringify( $val )  if ref $val eq 'HASH';
         $val  = _rotate( $val )     if ref $val eq 'ARRAY';
+        next unless defined $val;
         $str .= sprintf ' %s="%s"', _key( $key ), _val( $val );
     }
     return $str;
@@ -52,6 +53,7 @@ sub _key {
     $key =~ s/["'>=\/]//g;
     return $key;
 }
+
 sub _val {
     my $val = shift;
     $val = '' if $val =~ /^\s+$/;
@@ -177,6 +179,8 @@ Additional rules for keys and values:
 
 =over 4
 
+=item * any attribute with a value of undef will be skipped
+
 =item * no case-insenstive matches for attribute names in start tag
 
 =item * remove any occurance from keys: " ' > / = and spaces
